Module audit

Module audit 

Audit trail helpers: build and send structured JSON messages to Kafka.

Structs

Auditor
Wraps a Kafka instance for sending audit messages.

Traits

Audit
Trait for producing audit messages to a message broker.

Functions

maybe_send_audit
Send an audit message if a Kafka instance is configured.
send_audit
Build and send an audit message to Kafka.
send_auth_audit
Send a structured audit event for an /api/v1/auth/token attempt.