HwClusterMode

Enum HwClusterMode 

pub enum HwClusterMode {
    Pin,
    Unpin,
}
Whether the hw cluster operation moves nodes into the target (Pin) or releases them back (Unpin).

Variants



Pin

Move nodes matching the hardware pattern from the parent cluster into the target cluster.



Unpin

Move nodes matching the hardware pattern from the target cluster back to the parent cluster.