pub struct Image {
pub name: String,
pub ref_name: Option<String>,
pub base_or_ims: BaseOrIms,
pub configuration: Option<String>,
pub configuration_group_names: Option<Vec<String>>,
pub description: Option<String>,
}Expand description
An image definition in the SAT file images section.
Fields
name: StringUnique name for this image; used as the cross-reference target for image_ref.
ref_name: Option<String>Optional alias used to reference this image from session templates.
base_or_ims: BaseOrImsBase image source (IMS or product catalog), in legacy or current format.
configuration: Option<String>CFS configuration to apply when building the image.
configuration_group_names: Option<Vec<String>>HSM group names passed as Ansible group vars during the image build.
description: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Image
impl<'de> Deserialize<'de> for Image
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more