Module sessiontemplate

Module sessiontemplate 

struct to represent the session_templates section in SAT file

Structs

BootSet
A single boot set defining the kernel, network, and node targeting for a BOS session template.
BosParamters
BOS boot parameters containing a map of named boot sets.
SessionTemplate
A BOS session template linking an image, configuration, and boot parameters for a set of nodes.

Enums

Arch
Processor architecture for a boot set.
Image
Image reference within a session template — either an IMS image or a cross-reference to another SAT image.
ImsDetails
How the IMS image is referenced — by name or by UUID.