Audit trail helpers: build and send structured JSON messages to Kafka.
Structs
Traits
- Audit
- Trait for producing audit messages to a message broker.
Functions
- maybe_
send_ audit - Send an audit message if a Kafka instance is configured.
- send_
audit - Build and send an audit message to Kafka.
- send_
auth_ audit - Send a structured audit event for an
/api/v1/auth/tokenattempt.